
:orphan:

.. _sphx_glr_documentation_auto_examples_sg_execution_times:

Computation times
=================
**00:25.940** total execution time for **documentation_auto_examples** files:

- **00:25.940**: :ref:`sphx_glr_documentation_auto_examples_plot_classification.py` (``plot_classification.py``)
- **00:00.000**: :ref:`sphx_glr_documentation_auto_examples_plot_lle_digits.py` (``plot_lle_digits.py``)
- **00:00.000**: :ref:`sphx_glr_documentation_auto_examples_plot_multioutput_face_completion.py` (``plot_multioutput_face_completion.py``)
- **00:00.000**: :ref:`sphx_glr_documentation_auto_examples_plot_nca_classification.py` (``plot_nca_classification.py``)
- **00:00.000**: :ref:`sphx_glr_documentation_auto_examples_plot_nca_dim_reduction.py` (``plot_nca_dim_reduction.py``)
- **00:00.000**: :ref:`sphx_glr_documentation_auto_examples_plot_nearest_centroid.py` (``plot_nearest_centroid.py``)
- **00:00.000**: :ref:`sphx_glr_documentation_auto_examples_plot_regression.py` (``plot_regression.py``)
